@@ -1,5 +1,5 @@
 """
-    Copyright (C) 2022  Michael Ablassmeier <abi@grinser.de>
+    Copyright (C) 2023  Michael Ablassmeier <abi@grinser.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ from paramiko import (  # pylint: disable=import-error
 )
 
 from libvirtnbdbackup.ssh import exceptions
-from libvirtnbdbackup.common.processinfo import processInfo
+from libvirtnbdbackup.processinfo import processInfo
 
 log = logging.getLogger("ssh")
 
@@ -75,7 +75,7 @@ class client:
             )
         except Exception as e:
             log.exception(e)
-            raise exceptions.sshError(f"Unknown exception occured: {e}")
+            raise exceptions.sshError(f"Unknown exception occurred: {e}")
 
     @property
     def sftp(self) -> SFTPClient:
@@ -128,9 +128,18 @@ class client:
         log.debug("Executing remote command: [%s]", cmd)
         ret, err, out = self._execute(cmd)
         if ret != 0:
+            log.error(
+                "Executing command failed, return code: [%s] stderr: [%s], stdout: [%s]",
+                ret,
+                err,
+                out,
+            )
             if logFile:
-                _, _, err = self._execute(f"cat {logFile}")
-            raise exceptions.sshError(f"Error during remote command: [{cmd}]: [{err}]")
+                log.debug("Attempting to catch errors from logfile")
+                _, _, logerr = self._execute(f"cat {logFile}")
+            raise exceptions.sshError(
+                f"Error during remote command: [{cmd}]: [{err}] [{logerr}]"
+            )
 
         if pidFile:
             log.debug("PIDfile: [%s]", pidFile)
@@ -138,7 +147,7 @@ class client:
             pid = int(pidOut)
             log.debug("PID: [%s]", pid)
 
-        return processInfo(pid, logFile, err, out)
+        return processInfo(pid, logFile, err, out, pidFile)
 
     def disconnect(self):
         """Disconnect"""
